==> Data-Context-v0.1.10.tar.gz: Data-Context-v0.1.10/lib/Data/Context/Loader/File/JS.pm <==
package Data::Context::Loader::File::JS;

# Created on: 2013-10-29 17:34:33
# Create by:  Ivan Wills
# $Id$
# $Revision$, $HeadURL$, $Date$
# $Revision$, $Source$, $Date$

use Moose;
use version;
use Carp;
use Data::Dumper qw/Dumper/;
use English qw/ -no_match_vars /;

our $VERSION     = version->new('0.1.10');

extends 'Data::Context::Loader::File';

has '+module' => (
    default => 'JSON',
);

sub loader {
    my ($self, $file) = @_;
    return JSON->new->utf8->relaxed->shrink->decode($file);
}

1;

__END__

=head1 NAME

Data::Context::Loader::File::JS - <One-line description of module's purpose>

=head1 VERSION

This documentation refers to Data::Context::Loader::File::JS version 0.1.10

=head1 SYNOPSIS

   use Data::Context::Loader::File::JS;

   # Brief but working code example(s) here showing the most common usage(s)
   # This section will be as far as many users bother reading, so make it as
   # educational and exemplary as possible.

=head1 DESCRIPTION

=head1 SUBROUTINES/METHODS

=head2 C<loader ($file)>

Loads the file as loose JSON

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.

Please report problems to Ivan Wills (ivan.wills@gmail.com).

Patches are welcome.

=head1 AUTHOR

Ivan Wills - (ivan.wills@gmail.com)

=head1 LICENSE AND COPYRIGHT

Copyright (c) 2013 Ivan Wills (14 Mullion Close, Hornsby Heights, NSW Australia 2077).
All rights reserved.

This module is free software; you can redistribute it and/or modify it under
the same terms as Perl itself. See L<perlartistic>.  This program is
distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.

=cut

==> Data-Context-0.2.tar.gz: Data-Context-0.2/lib/Data/Context/Loader/File/JS.pm <==
package Data::Context::Loader::File::JS;

# Created on: 2013-10-29 17:34:33
# Create by:  Ivan Wills
# $Id$
# $Revision$, $HeadURL$, $Date$
# $Revision$, $Source$, $Date$

use Moose;
use version;
use Carp;
use Data::Dumper qw/Dumper/;
use English qw/ -no_match_vars /;

our $VERSION     = version->new('0.2');

extends 'Data::Context::Loader::File';

has '+module' => (
    default => 'JSON',
);

sub loader {
    my ($self, $file) = @_;
    return JSON->new->utf8->relaxed->shrink->decode($file);
}

1;

__END__

=head1 NAME

Data::Context::Loader::File::JS - <One-line description of module's purpose>

=head1 VERSION

This documentation refers to Data::Context::Loader::File::JS version 0.2

=head1 SYNOPSIS

   use Data::Context::Loader::File::JS;

   # Brief but working code example(s) here showing the most common usage(s)
   # This section will be as far as many users bother reading, so make it as
   # educational and exemplary as possible.

=head1 DESCRIPTION

=head1 SUBROUTINES/METHODS

=head2 C<loader ($file)>

Loads the file as loose JSON

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.

Please report problems to Ivan Wills (ivan.wills@gmail.com).

Patches are welcome.

=head1 AUTHOR

Ivan Wills - (ivan.wills@gmail.com)

=head1 LICENSE AND COPYRIGHT

Copyright (c) 2013 Ivan Wills (14 Mullion Close, Hornsby Heights, NSW Australia 2077).
All rights reserved.

This module is free software; you can redistribute it and/or modify it under
the same terms as Perl itself. See L<perlartistic>.  This program is
distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.

=cut
